==> huaweicloudsdkcbh-3.1.83-py2.py3-none-any.whl: huaweicloudsdkcbh/v2/model/list_instances_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstancesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'instance': 'list[InstanceDetail]'
    }

    attribute_map = {
        'total': 'total',
        'instance': 'instance'
    }

    def __init__(self, total=None, instance=None):
        """ListInstancesResponse

        The model defined in huaweicloud sdk

        :param total: 云堡垒机实例总数。
        :type total: int
        :param instance: 云堡垒机实例列表信息。
        :type instance: list[:class:`huaweicloudsdkcbh.v2.InstanceDetail`]
        """
        
        super(ListInstancesResponse, self).__init__()

        self._total = None
        self._instance = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if instance is not None:
            self.instance = instance

    @property
    def total(self):
        """Gets the total of this ListInstancesResponse.

        云堡垒机实例总数。

        :return: The total of this ListInstancesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListInstancesResponse.

        云堡垒机实例总数。

        :param total: The total of this ListInstancesResponse.
        :type total: int
        """
        self._total = total

    @property
    def instance(self):
        """Gets the instance of this ListInstancesResponse.

        云堡垒机实例列表信息。

        :return: The instance of this ListInstancesResponse.
        :rtype: list[:class:`huaweicloudsdkcbh.v2.InstanceDetail`]
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        """Sets the instance of this ListInstancesResponse.

        云堡垒机实例列表信息。

        :param instance: The instance of this ListInstancesResponse.
        :type instance: list[:class:`huaweicloudsdkcbh.v2.InstanceDetail`]
        """
        self._instance = instance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstancesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbh-3.1.153-py2.py3-none-any.whl: huaweicloudsdkcbh/v2/model/list_instances_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstancesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'instance': 'list[InstanceDetail]'
    }

    attribute_map = {
        'total': 'total',
        'instance': 'instance'
    }

    def __init__(self, total=None, instance=None):
        r"""ListInstancesResponse

        The model defined in huaweicloud sdk

        :param total: 云堡垒机实例总数。
        :type total: int
        :param instance: 云堡垒机实例列表信息。
        :type instance: list[:class:`huaweicloudsdkcbh.v2.InstanceDetail`]
        """
        
        super(ListInstancesResponse, self).__init__()

        self._total = None
        self._instance = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if instance is not None:
            self.instance = instance

    @property
    def total(self):
        r"""Gets the total of this ListInstancesResponse.

        云堡垒机实例总数。

        :return: The total of this ListInstancesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListInstancesResponse.

        云堡垒机实例总数。

        :param total: The total of this ListInstancesResponse.
        :type total: int
        """
        self._total = total

    @property
    def instance(self):
        r"""Gets the instance of this ListInstancesResponse.

        云堡垒机实例列表信息。

        :return: The instance of this ListInstancesResponse.
        :rtype: list[:class:`huaweicloudsdkcbh.v2.InstanceDetail`]
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        r"""Sets the instance of this ListInstancesResponse.

        云堡垒机实例列表信息。

        :param instance: The instance of this ListInstancesResponse.
        :type instance: list[:class:`huaweicloudsdkcbh.v2.InstanceDetail`]
        """
        self._instance = instance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstancesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
